@@ -25,7 +25,7 @@ from boto3.exceptions import ResourceNotExistsError, UnknownAPIVersionError
 from .resources.factory import ResourceFactory
 
 
-class Session(object):
+class Session:
     """
     A session stores configuration state and allows you to create service
     clients and resources.
@@ -45,9 +45,16 @@ class Session(object):
     :param profile_name: The name of a profile to use. If not given, then
                          the default profile is used.
     """
-    def __init__(self, aws_access_key_id=None, aws_secret_access_key=None,
-                 aws_session_token=None, region_name=None,
-                 botocore_session=None, profile_name=None):
+
+    def __init__(
+        self,
+        aws_access_key_id=None,
+        aws_secret_access_key=None,
+        aws_session_token=None,
+        region_name=None,
+        botocore_session=None,
+        profile_name=None,
+    ):
         if botocore_session is not None:
             self._session = botocore_session
         else:
@@ -56,8 +63,9 @@ class Session(object):
 
         # Setup custom user-agent string if it isn't already customized
         if self._session.user_agent_name == 'Botocore':
-            botocore_info = 'Botocore/{0}'.format(
-                self._session.user_agent_version)
+            botocore_info = 'Botocore/{}'.format(
+                self._session.user_agent_version
+            )
             if self._session.user_agent_extra:
                 self._session.user_agent_extra += ' ' + botocore_info
             else:
@@ -70,20 +78,23 @@ class Session(object):
 
         if aws_access_key_id or aws_secret_access_key or aws_session_token:
             self._session.set_credentials(
-                aws_access_key_id, aws_secret_access_key, aws_session_token)
+                aws_access_key_id, aws_secret_access_key, aws_session_token
+            )
 
         if region_name is not None:
             self._session.set_config_variable('region', region_name)
 
         self.resource_factory = ResourceFactory(
-            self._session.get_component('event_emitter'))
+            self._session.get_component('event_emitter')
+        )
         self._setup_loader()
         self._register_default_handlers()
 
     def __repr__(self):
-        return '{0}(region_name={1})'.format(
+        return '{}(region_name={})'.format(
             self.__class__.__name__,
-            repr(self._session.get_config_variable('region')))
+            repr(self._session.get_config_variable('region')),
+        )
 
     @property
     def profile_name(self):
@@ -119,7 +130,8 @@ class Session(object):
         """
         self._loader = self._session.get_component('data_loader')
         self._loader.search_paths.append(
-            os.path.join(os.path.dirname(__file__), 'data'))
+            os.path.join(os.path.dirname(__file__), 'data')
+        )
 
     def get_available_services(self):
         """
@@ -149,8 +161,9 @@ class Session(object):
         """
         return self._session.get_available_partitions()
 
-    def get_available_regions(self, service_name, partition_name='aws',
-                              allow_non_regional=False):
+    def get_available_regions(
+        self, service_name, partition_name='aws', allow_non_regional=False
+    ):
         """Lists the region and endpoint names of a particular partition.
 
         :type service_name: string
@@ -169,8 +182,10 @@ class Session(object):
         :return: Returns a list of endpoint names (e.g., ["us-east-1"]).
         """
         return self._session.get_available_regions(
-            service_name=service_name, partition_name=partition_name,
-            allow_non_regional=allow_non_regional)
+            service_name=service_name,
+            partition_name=partition_name,
+            allow_non_regional=allow_non_regional,
+        )
 
     def get_credentials(self):
         """
@@ -194,10 +209,19 @@ class Session(object):
         """
         return self._session.get_partition_for_region(region_name)
 
-    def client(self, service_name, region_name=None, api_version=None,
-               use_ssl=True, verify=None, endpoint_url=None,
-               aws_access_key_id=None, aws_secret_access_key=None,
-               aws_session_token=None, config=None):
+    def client(
+        self,
+        service_name,
+        region_name=None,
+        api_version=None,
+        use_ssl=True,
+        verify=None,
+        endpoint_url=None,
+        aws_access_key_id=None,
+        aws_secret_access_key=None,
+        aws_session_token=None,
+        config=None,
+    ):
         """
         Create a low-level service client by name.
 
@@ -268,16 +292,31 @@ class Session(object):
 
         """
         return self._session.create_client(
-            service_name, region_name=region_name, api_version=api_version,
-            use_ssl=use_ssl, verify=verify, endpoint_url=endpoint_url,
+            service_name,
+            region_name=region_name,
+            api_version=api_version,
+            use_ssl=use_ssl,
+            verify=verify,
+            endpoint_url=endpoint_url,
             aws_access_key_id=aws_access_key_id,
             aws_secret_access_key=aws_secret_access_key,
-            aws_session_token=aws_session_token, config=config)
+            aws_session_token=aws_session_token,
+            config=config,
+        )
 
-    def resource(self, service_name, region_name=None, api_version=None,
-                 use_ssl=True, verify=None, endpoint_url=None,
-                 aws_access_key_id=None, aws_secret_access_key=None,
-                 aws_session_token=None, config=None):
+    def resource(
+        self,
+        service_name,
+        region_name=None,
+        api_version=None,
+        use_ssl=True,
+        verify=None,
+        endpoint_url=None,
+        aws_access_key_id=None,
+        aws_secret_access_key=None,
+        aws_session_token=None,
+        config=None,
+    ):
         """
         Create a resource service client by name.
 
@@ -350,19 +389,24 @@ class Session(object):
         """
         try:
             resource_model = self._loader.load_service_model(
-                service_name, 'resources-1', api_version)
+                service_name, 'resources-1', api_version
+            )
         except UnknownServiceError:
             available = self.get_available_resources()
             has_low_level_client = (
-                service_name in self.get_available_services())
-            raise ResourceNotExistsError(service_name, available,
-                                         has_low_level_client)
+                service_name in self.get_available_services()
+            )
+            raise ResourceNotExistsError(
+                service_name, available, has_low_level_client
+            )
         except DataNotFoundError:
             # This is because we've provided an invalid API version.
             available_api_versions = self._loader.list_api_versions(
-                service_name, 'resources-1')
+                service_name, 'resources-1'
+            )
             raise UnknownAPIVersionError(
-                service_name, api_version, ', '.join(available_api_versions))
+                service_name, api_version, ', '.join(available_api_versions)
+            )
 
         if api_version is None:
             # Even though botocore's load_service_model() can handle
@@ -381,7 +425,8 @@ class Session(object):
             # and loader.determine_latest_version(..., 'resources-1')
             # both load the same api version of the file.
             api_version = self._loader.determine_latest_version(
-                service_name, 'resources-1')
+                service_name, 'resources-1'
+            )
 
         # Creating a new resource instance requires the low-level client
         # and service model, the resource version and resource JSON data.
@@ -394,28 +439,35 @@ class Session(object):
         else:
             config = Config(user_agent_extra='Resource')
         client = self.client(
-            service_name, region_name=region_name, api_version=api_version,
-            use_ssl=use_ssl, verify=verify, endpoint_url=endpoint_url,
+            service_name,
+            region_name=region_name,
+            api_version=api_version,
+            use_ssl=use_ssl,
+            verify=verify,
+            endpoint_url=endpoint_url,
             aws_access_key_id=aws_access_key_id,
             aws_secret_access_key=aws_secret_access_key,
-            aws_session_token=aws_session_token, config=config)
+            aws_session_token=aws_session_token,
+            config=config,
+        )
         service_model = client.meta.service_model
 
         # Create a ServiceContext object to serve as a reference to
         # important read-only information about the general service.
         service_context = boto3.utils.ServiceContext(
-            service_name=service_name, service_model=service_model,
+            service_name=service_name,
+            service_model=service_model,
             resource_json_definitions=resource_model['resources'],
             service_waiter_model=boto3.utils.LazyLoadedWaiterModel(
                 self._session, service_name, api_version
-            )
+            ),
         )
 
         # Create the service resource class.
         cls = self.resource_factory.load_from_definition(
             resource_name=service_name,
             single_resource_json_definition=resource_model['service'],
-            service_context=service_context
+            service_context=service_context,
         )
 
         return cls(client=client)
@@ -426,40 +478,50 @@ class Session(object):
         self._session.register(
             'creating-client-class.s3',
             boto3.utils.lazy_call(
-                'boto3.s3.inject.inject_s3_transfer_methods'))
+                'boto3.s3.inject.inject_s3_transfer_methods'
+            ),
+        )
         self._session.register(
             'creating-resource-class.s3.Bucket',
-            boto3.utils.lazy_call(
-                'boto3.s3.inject.inject_bucket_methods'))
+            boto3.utils.lazy_call('boto3.s3.inject.inject_bucket_methods'),
+        )
         self._session.register(
             'creating-resource-class.s3.Object',
-            boto3.utils.lazy_call(
-                'boto3.s3.inject.inject_object_methods'))
+            boto3.utils.lazy_call('boto3.s3.inject.inject_object_methods'),
+        )
         self._session.register(
             'creating-resource-class.s3.ObjectSummary',
             boto3.utils.lazy_call(
-                'boto3.s3.inject.inject_object_summary_methods'))
+                'boto3.s3.inject.inject_object_summary_methods'
+            ),
+        )
 
         # DynamoDb customizations
         self._session.register(
             'creating-resource-class.dynamodb',
             boto3.utils.lazy_call(
-                'boto3.dynamodb.transform.register_high_level_interface'),
-            unique_id='high-level-dynamodb')
+                'boto3.dynamodb.transform.register_high_level_interface'
+            ),
+            unique_id='high-level-dynamodb',
+        )
         self._session.register(
             'creating-resource-class.dynamodb.Table',
             boto3.utils.lazy_call(
-                'boto3.dynamodb.table.register_table_methods'),
-            unique_id='high-level-dynamodb-table')
+                'boto3.dynamodb.table.register_table_methods'
+            ),
+            unique_id='high-level-dynamodb-table',
+        )
 
         # EC2 Customizations
         self._session.register(
             'creating-resource-class.ec2.ServiceResource',
-            boto3.utils.lazy_call(
-                'boto3.ec2.createtags.inject_create_tags'))
+            boto3.utils.lazy_call('boto3.ec2.createtags.inject_create_tags'),
+        )
 
         self._session.register(
             'creating-resource-class.ec2.Instance',
             boto3.utils.lazy_call(
                 'boto3.ec2.deletetags.inject_delete_tags',
-                event_emitter=self.events))
+                event_emitter=self.events,
+            ),
+        )
